# ECS DNS v0.1.7

[![PyPI](https://img.shields.io/pypi/v/ecs-dns}.svg)](https://pypi.python.org/pypi/ecs-dns)

Creates a Route 53 multi-value A record for ECS tasks which are assigned a public IP.

## Features

* Create a new A record in a multi-value set

## Usage

    pip install ecs-dns
    ecs-dns --help

## Credits

* Shaun Martin ([inhumantsar](https://github.com/inhumantsar)) [inhumantsar@protonmail.com](mailto:inhumantsar@protonmail.com)
